## Overview

Programmer for Picoboot3

Picoboot3 is a custom bootloader allowing firmware updates for Raspberry Pi Pico via UART/I2C. 

Before you can use this tool to write firmware, you'll need to set up Picoboot3 on your board.
More information on this can be found [here](https://github.com/IndoorCorgi/picoboot3).
